@@ -211,8 +211,8 @@ Radio::~Radio()
 	 radio->stop();
 
     QProcess *myProcess = new QProcess;
-     QString program = "dbus-send --system --type=method_call --dest=org.bluez $(dbus-send --system --print-reply --dest=org.bluez / org.bluez.Manager.ListAdapters | awk -F'\"' '/at/ {print $2}') org.bluez.Adapter.SetProperty string:Powered variant:boolean:false";
-    myProcess->execute(program);
+    // QString program = "dbus-send --system --type=method_call --dest=org.bluez $(dbus-send --system --print-reply --dest=org.bluez / org.bluez.Manager.ListAdapters | awk -F'\"' '/at/ {print $2}') org.bluez.Adapter.SetProperty string:Powered variant:boolean:false";
+    myProcess->execute("/opt/qradio/disablebluetooth.sh");
 
 
 }
